@@ -1,50 +1,9 @@
-/*************************************************************************
- * Copyright (C) 2014 by Hugo Pereira Da Costa <hugo.pereira@free.fr>    *
- *                                                                       *
- * This program is free software; you can redistribute it and/or modify  *
- * it under the terms of the GNU General Public License as published by  *
- * the Free Software Foundation; either version 2 of the License, or     *
- * (at your option) any later version.                                   *
- *                                                                       *
- * This program is distributed in the hope that it will be useful,       *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- * GNU General Public License for more details.                          *
- *                                                                       *
- * You should have received a copy of the GNU General Public License     *
- * along with this program; if not, write to the                         *
- * Free Software Foundation, Inc.,                                       *
- * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- *************************************************************************/
-
-//////////////////////////////////////////////////////////////////////////////
-// oxygenwindowmanager.cpp
-// pass some window mouse press/release/move event actions to window manager
-// -------------------
-//
-// Copyright (c) 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
-//
-// Largely inspired from BeSpin style
-// Copyright (C) 2007 Thomas Luebking <thomas.luebking@web.de>
-//
-// Permission is hereby granted, free of charge, to any person obtaining a copy
-// of this software and associated documentation files (the "Software"), to
-// deal in the Software without restriction, including without limitation the
-// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
-// sell copies of the Software, and to permit persons to whom the Software is
-// furnished to do so, subject to the following conditions:
-//
-// The above copyright notice and this permission notice shall be included in
-// all copies or substantial portions of the Software.
-//
-// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
-// IN THE SOFTWARE.
-//////////////////////////////////////////////////////////////////////////////
+/*
+    SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+    SPDX-FileCopyrightText: 2014 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+    SPDX-FileCopyrightText: 2007 Thomas Luebking <thomas.luebking@web.de>
+    SPDX-License-Identifier: GPL-2.0-or-later AND MIT
+*/
 
 #include "oxygenwindowmanager.h"
 #include "oxygenpropertynames.h"
@@ -322,7 +281,8 @@ namespace Oxygen
         _whiteList.insert( ExceptionId( QStringLiteral( "ViewSliders@kmix" ) ) );
         _whiteList.insert( ExceptionId( QStringLiteral( "Sidebar_Widget@konqueror" ) ) );
 
-        foreach( const QString& exception, StyleConfigData::windowDragWhiteList() )
+        const QStringList whiteList = StyleConfigData::windowDragWhiteList();
+        for ( const QString &exception : whiteList )
         {
             ExceptionId id( exception );
             if( !id.className().isEmpty() )
@@ -338,7 +298,9 @@ namespace Oxygen
         _blackList.insert( ExceptionId( QStringLiteral( "CustomTrackView@kdenlive" ) ) );
         _blackList.insert( ExceptionId( QStringLiteral( "MuseScore" ) ) );
         _blackList.insert( ExceptionId( QStringLiteral( "KGameCanvasWidget" ) ) );
-        foreach( const QString& exception, StyleConfigData::windowDragBlackList() )
+
+        const QStringList blackList = StyleConfigData::windowDragBlackList();
+        for ( const QString &exception : blackList )
         {
             ExceptionId id( exception );
             if( !id.className().isEmpty() )
@@ -594,7 +556,7 @@ namespace Oxygen
 
         // list-based blacklisted widgets
         QString appName( qApp->applicationName() );
-        foreach( const ExceptionId& id, _blackList )
+        for ( const ExceptionId &id : std::as_const(_blackList) )
         {
             if( !id.appName().isEmpty() && id.appName() != appName ) continue;
             if( id.className() == QStringLiteral( "*" ) && !id.appName().isEmpty() )
@@ -615,7 +577,7 @@ namespace Oxygen
     {
 
         QString appName( qApp->applicationName() );
-        foreach( const ExceptionId& id, _whiteList )
+        for ( const ExceptionId &id : std::as_const(_whiteList) )
         {
             if( !id.appName().isEmpty() && id.appName() != appName ) continue;
             if( widget->inherits( id.className().toLatin1().data() ) ) return true;
@@ -723,7 +685,7 @@ namespace Oxygen
             // gather options to retrieve checkbox subcontrol rect
             QStyleOptionGroupBox opt;
             opt.initFrom( groupBox );
-            if( groupBox->isFlat() ) opt.features |= QStyleOptionFrameV2::Flat;
+            if( groupBox->isFlat() ) opt.features |= QStyleOptionFrame::Flat;
             opt.lineWidth = 1;
             opt.midLineWidth = 0;
             opt.text = groupBox->title();
